pub enum DeploymentMode {
Desktop,
SelfHost,
Cloud,
}Expand description
Deployment environment controlling which features and source types are available.
- Desktop: Native Tauri app. Full local filesystem access + native file picker.
- SelfHost: Docker/VPS browser UI. Local filesystem access (server-side paths).
- Cloud: Managed cloud service. No local filesystem access.
Variants
Implementations
Sourceimpl DeploymentMode
impl DeploymentMode
Sourcepub fn capabilities(&self) -> DeploymentCapabilities
pub fn capabilities(&self) -> DeploymentCapabilities
Returns the set of capabilities for this deployment mode.
Sourcepub fn allows_source_type(&self, source_type: &str) -> bool
pub fn allows_source_type(&self, source_type: &str) -> bool
Returns true if the given source type is allowed in this mode.