pub async fn insert_thread_tweets(
pool: &DbPool,
thread_id: i64,
tweets: &[ThreadTweet],
) -> Result<(), StorageError>Expand description
Insert all tweets for a thread atomically using a transaction.
Either all tweets are inserted or none are (rollback on failure).