authenticate_callback

Function authenticate_callback 

pub async fn authenticate_callback(
    client_id: &str,
    host: &str,
    port: u16,
) -> Result<Tokens, XApiError>
Perform OAuth 2.0 PKCE authentication with a local callback server.

Starts a temporary HTTP server, opens the browser to the authorization URL, and captures the callback with the authorization code automatically.